@@ -4,6 +4,29 @@ import pandas as pd
 from dateutil import parser
 from lxml import etree, objectify
 import dateutil
+from jsonschema import validate
+import jsonschema
+
+
+def validate_with_schema(file_path, schema_path):
+    if "json" in file_path.lower():
+        file_content = json.load(open(file_path, "rb"))
+        schema_content = json.load(open(schema_path, "rb"))
+        try:
+            validate(instance=file_content, schema=schema_content)
+            return True
+        except jsonschema.exceptions.ValidationError as err:
+            return False
+        return False
+    elif "xml" in file_path:
+        try:
+            import lxml
+            xml_file = lxml.etree.parse(file_path)
+            xml_validator = lxml.etree.XMLSchema(file=schema_path)
+            is_valid = xml_validator.validate(xml_file)
+            return is_valid
+        except:
+            return False
 
 
 def apply(file_path, return_obj_df=None, parameters=None):
@@ -108,6 +131,7 @@ def apply_json(file_path, return_obj_df=None, parameters=None):
     for el in obj_stream:
         obj_type[el["object_id"]] = el[prefix + "type"]
         el["object_type"] = el[prefix + "type"]
+        del el[prefix + "type"]
         for k2 in el[prefix + "ovmap"]:
             el["object_" + k2] = el[prefix + "ovmap"][k2]
         del el[prefix + "ovmap"]
